@@ -17,7 +17,6 @@ import multiprocessing
 from multiprocessing.pool import ThreadPool
 from tqdm import tqdm
 from questionary import prompt
-import coloredlogs
 
 import requests
 from getpass import getpass
@@ -378,7 +377,7 @@ class SafetyCulture:
         last_modified = (
             modified_after if modified_after is not None else "2000-01-01T00:00:00.000Z"
         )
-        modified_before = modified_before if modified_before is not None else today
+        modified_before = modified_before if modified_before is not None else None
 
         if type(limit) is not int:
             logger.warning("Limit must be an integer. Defaulting to 1000")
@@ -410,8 +409,10 @@ class SafetyCulture:
         search_url = (
             self.audit_url
             + f"search?field=audit_id&field=modified_at&order={order}&limit={limit}"
-            f"&modified_after={last_modified}&modified_before={modified_before}"
+            f"&modified_after={last_modified}"
         )
+        if modified_before is not None:
+            self.audit_url = self.audit_url + f'&modified_before={modified_before}'
         log_string = "\nInitiating audit_discovery with the parameters: " + "\n"
         log_string += "template_id    = " + str(template_id) + "\n"
         log_string += "modified_after = " + str(last_modified) + "\n"
@@ -443,6 +444,8 @@ class SafetyCulture:
         response = self.authenticated_request_get(search_url)
         result = response.json() if response.status_code == requests.codes.ok else None
         number_discovered = str(result["total"]) if result is not None else "0"
+        if not backlog:
+            logger.info(f'Discovered {number_discovered} inspections.')
         log_message = (
             "on audit_discovery: "
             + number_discovered
